
# Slot: object




URI: [biolink:gene_regulatory_relationship_object](https://w3id.org/biolink/vocab/gene_regulatory_relationship_object)


## Domain and Range

[GeneRegulatoryRelationship](GeneRegulatoryRelationship.md) &#8594;  <sub>1..1</sub> [GeneOrGeneProduct](GeneOrGeneProduct.md)

## Parents

 *  is_a: [object](object.md)

## Children


## Used by

 * [GeneRegulatoryRelationship](GeneRegulatoryRelationship.md)
